==> opennms-services-1.7.91-sources.jar: org/opennms/netmgt/utils/Querier.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2005 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 2008 Mar 20: Remove commented-out System.err.println. - dj@opennms.org
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.utils;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.sql.DataSource;

import org.opennms.core.utils.DBUtils;


public class Querier extends JDBCTemplate implements RowProcessor {
    private int m_count;
    private RowProcessor m_rowProcessor;
    public Querier(DataSource db, String sql, RowProcessor rowProcessor) {
        super(db, sql);
        if (rowProcessor == null)
            m_rowProcessor = this;
        else 
            m_rowProcessor = rowProcessor;
        m_count = 0;
    }
     
    public Querier(DataSource db, String sql) {
        this(db, sql, null);
    }
     
    public int getCount() {
        return m_count;
    }
     
    protected void executeStmt(PreparedStatement stmt) throws SQLException {
        final DBUtils d = new DBUtils(getClass());
        try {
            ResultSet rs = stmt.executeQuery();
            d.watch(rs);
            m_count = 0;
            while (rs.next()) {
                m_rowProcessor.processRow(rs);
                m_count++;
            }
        } finally {
            d.cleanUp();
        }
    }

    public void processRow(ResultSet rs) throws SQLException {
    }

 }

==> opennms-services-1.8.12-sources.jar: org/opennms/netmgt/utils/Querier.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2005 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 2008 Mar 20: Remove commented-out System.err.println. - dj@opennms.org
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.utils;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.sql.DataSource;

import org.opennms.core.utils.DBUtils;


/**
 * <p>Querier class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public class Querier extends JDBCTemplate implements RowProcessor {
    private int m_count;
    private RowProcessor m_rowProcessor;
    /**
     * <p>Constructor for Querier.</p>
     *
     * @param db a {@link javax.sql.DataSource} object.
     * @param sql a {@link java.lang.String} object.
     * @param rowProcessor a {@link org.opennms.netmgt.utils.RowProcessor} object.
     */
    public Querier(DataSource db, String sql, RowProcessor rowProcessor) {
        super(db, sql);
        if (rowProcessor == null)
            m_rowProcessor = this;
        else 
            m_rowProcessor = rowProcessor;
        m_count = 0;
    }
     
    /**
     * <p>Constructor for Querier.</p>
     *
     * @param db a {@link javax.sql.DataSource} object.
     * @param sql a {@link java.lang.String} object.
     */
    public Querier(DataSource db, String sql) {
        this(db, sql, null);
    }
     
    /**
     * <p>getCount</p>
     *
     * @return a int.
     */
    public int getCount() {
        return m_count;
    }
     
    /** {@inheritDoc} */
    protected void executeStmt(PreparedStatement stmt) throws SQLException {
        final DBUtils d = new DBUtils(getClass());
        try {
            ResultSet rs = stmt.executeQuery();
            d.watch(rs);
            m_count = 0;
            while (rs.next()) {
                m_rowProcessor.processRow(rs);
                m_count++;
            }
        } finally {
            d.cleanUp();
        }
    }

    /** {@inheritDoc} */
    public void processRow(ResultSet rs) throws SQLException {
    }

 }
